=== modified file 'olive/__init__.py'
--- olive/__init__.py	2006-09-25 01:58:44 +0000
+++ olive/__init__.py	2006-09-27 19:52:46 +0000
@@ -37,33 +37,33 @@
 # Olive GTK UI version
 __version__ = '0.11.0'
 
+# Load the glade file
+if sys.platform == 'win32':
+	gladefile = os.path.dirname(sys.executable) + "/share/olive/olive.glade"
+else:
+	gladefile = "/usr/share/olive/olive.glade"
+
+if not os.path.exists(gladefile):
+	# Load from current directory if not installed
+	gladefile = "olive.glade"
+	# Check again
+	if not os.path.exists(gladefile):
+		# Fail
+		print _('Glade file cannot be found.')
+		sys.exit(1)
+
 class OliveGtk:
     """ The main Olive GTK frontend class. This is called when launching the
     program. """
     
     def __init__(self):
-        # Load the glade file
-        if sys.platform == 'win32':
-            self.gladefile = os.path.dirname(sys.executable) + "/share/olive/olive.glade"
-        else:
-            self.gladefile = "/usr/share/olive/olive.glade"
-
-        if not os.path.exists(self.gladefile):
-            # Load from current directory if not installed
-            self.gladefile = "olive.glade"
-            # Check again
-            if not os.path.exists(self.gladefile):
-                # Fail
-                print _('Glade file cannot be found.')
-                sys.exit(1)
-
-        self.toplevel = gtk.glade.XML(self.gladefile, 'window_main', 'olive-gtk')
+        self.toplevel = gtk.glade.XML(gladefile, 'window_main', 'olive-gtk')
         
         self.window = self.toplevel.get_widget('window_main')
         
         self.pref = OlivePreferences()
         self.comm = OliveCommunicator(self.toplevel, self.pref)
-        handler = OliveHandler(self.gladefile, self.comm)
+        handler = OliveHandler(self.comm)
         
         # Dictionary for signal_autoconnect
         dic = { "on_window_main_destroy": gtk.main_quit,
@@ -226,7 +226,7 @@
                 for rpath, id, kind in delta.added:
                     if rpath == filename:
                         status = 'added'
-                for rpath, id, kind, text_modified, meta_modified in delta.removed:
+                for rpath, id, kind in delta.removed:
                     if rpath == filename:
                         status = 'removed'
                 for rpath, id, kind, text_modified, meta_modified in delta.modified:

=== modified file 'olive/add.py'
--- olive/add.py	2006-09-27 18:00:19 +0000
+++ olive/add.py	2006-09-27 19:52:46 +0000
@@ -21,21 +21,20 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+
+import gtk
+import gtk.glade
 
 import bzrlib.add
 import bzrlib.errors as errors
 
+from olive import gladefile
+
 class OliveAdd:
     """ Display the Add file(s) dialog and perform the needed actions. """
-    def __init__(self, gladefile, wt, wtpath, selected=[]):
+    def __init__(self, wt, wtpath, selected=[]):
         """ Initialize the Add file(s) dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_add', 'olive-gtk')
+        self.glade = gtk.glade.XML(gladefile, 'window_add', 'olive-gtk')
         
         self.window = self.glade.get_widget('window_add')
         

=== modified file 'olive/bookmark.py'
--- olive/bookmark.py	2006-09-27 17:49:18 +0000
+++ olive/bookmark.py	2006-09-27 19:52:46 +0000
@@ -21,18 +21,16 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+
+import gtk
+import gtk.glade
+from olive import gladefile
 
 class OliveBookmark:
     """ Display the Edit bookmark dialog and perform the needed actions. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Edit bookmark dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_bookmark', 'olive-gtk')
+        self.glade = gtk.glade.XML(gladefile, 'window_bookmark', 'olive-gtk')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/branch.py'
--- olive/branch.py	2006-09-27 17:49:18 +0000
+++ olive/branch.py	2006-09-27 19:52:46 +0000
@@ -21,20 +21,18 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+
+import gtk
+import gtk.glade
 
 import bzrlib.errors as errors
+from olive import gladefile
 
 class OliveBranch:
     """ Display branch dialog and perform the needed operations. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Branch dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_branch', 'olive-gtk')
+        self.glade = gtk.glade.XML(gladefile, 'window_branch', 'olive-gtk')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/checkout.py'
--- olive/checkout.py	2006-09-27 17:49:18 +0000
+++ olive/checkout.py	2006-09-27 19:52:46 +0000
@@ -21,20 +21,19 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+
+import gtk
+import gtk.glade
 
 import bzrlib.errors as errors
 
+from olive import gladefile
+
 class OliveCheckout:
     """ Display checkout dialog and perform the needed operations. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Checkout dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_checkout', 'olive-gtk')
+        self.glade = gtk.glade.XML('window_checkout', 'olive-gtk')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/commit.py'
--- olive/commit.py	2006-09-27 17:49:18 +0000
+++ olive/commit.py	2006-09-27 19:52:46 +0000
@@ -35,13 +35,13 @@
 from bzrlib.workingtree import WorkingTree
 
 from dialog import error_dialog
+from olive import gladefile
 
 class OliveCommit:
     """ Display Commit dialog and perform the needed actions. """
-    def __init__(self, gladefile, wt, wtpath):
+    def __init__(self, wt, wtpath):
         """ Initialize the Commit dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_commit', 'olive-gtk')
+        self.glade = gtk.glade.XML(gladefile, 'window_commit', 'olive-gtk')
         
         self.wt = wt
         self.wtpath = wtpath

=== removed file 'olive/diff.py'
--- olive/diff.py	2006-09-27 17:49:18 +0000
+++ olive/diff.py	1970-01-01 00:00:00 +0000
@@ -1,179 +0,0 @@
-# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
-#
-# Some parts of the code:
-# Copyright (C) 2005 by Canonical Ltd.
-# Author: Scott James Remnant <scott@ubuntu.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-import sys
-
-from cStringIO import StringIO
-
-try:
-    import pygtk
-    pygtk.require("2.0")
-except:
-    pass
-try:
-    import gtk
-    import gtk.glade
-    import gobject
-    import pango
-except:
-    sys.exit(1)
-
-try:
-    import gtksourceview
-    have_gtksourceview = True
-except ImportError:
-    have_gtksourceview = False
-
-import bzrlib
-
-from bzrlib.diff import show_diff_trees
-import bzrlib.errors as errors
-from bzrlib.workingtree import WorkingTree
-
-class OliveDiff:
-    """ Display Diff window and perform the needed actions. """
-    def __init__(self, gladefile, comm):
-        """ Initialize the Diff window. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_diff', 'olive-gtk')
-        
-        # Communication object
-        self.comm = comm
-        
-        # Get some important widgets
-        self.window = self.glade.get_widget('window_diff')
-        self.treeview = self.glade.get_widget('treeview_diff_files')
-
-        # Check if current location is a branch
-        try:
-            (self.wt, path) = WorkingTree.open_containing(self.comm.get_path())
-            branch = self.wt.branch
-        except errors.NotBranchError:
-            self.notbranch = True
-            return
-        except:
-            raise
-
-        file_id = self.wt.path2id(path)
-
-        self.notbranch = False
-        if file_id is None:
-            self.notbranch = True
-            return
-        
-        # Set the old working tree
-        self.old_tree = self.wt.branch.repository.revision_tree(self.wt.branch.last_revision())
-        
-        # Dictionary for signal_autoconnect
-        dic = { "on_button_diff_close_clicked": self.close,
-                "on_treeview_diff_files_cursor_changed": self.cursor_changed }
-        
-        # Connect the signals to the handlers
-        self.glade.signal_autoconnect(dic)
-        
-        # Create the file list
-        self._create_file_view()
-        
-        # Generate initial diff
-        self._init_diff()
-    
-    def display(self):
-        """ Display the Diff window. """
-        if self.notbranch:
-            error_dialog(_('Directory is not a branch'),
-                                     _('You can perform this action only in a branch.'))
-            self.close()
-        else:
-            self.window.show_all()
-    
-    def _create_file_view(self):
-        """ Create the list of files. """
-        self.model = gtk.TreeStore(str, str)
-        self.treeview.set_model(self.model)
-        
-        cell = gtk.CellRendererText()
-        cell.set_property("width-chars", 20)
-        column = gtk.TreeViewColumn()
-        column.pack_start(cell, expand=True)
-        column.add_attribute(cell, "text", 0)
-        self.treeview.append_column(column)
-        
-        if have_gtksourceview:
-            self.buffer = gtksourceview.SourceBuffer()
-            slm = gtksourceview.SourceLanguagesManager()
-            gsl = slm.get_language_from_mime_type("text/x-patch")
-            self.buffer.set_language(gsl)
-            self.buffer.set_highlight(True)
-
-            sourceview = gtksourceview.SourceView(self.buffer)
-        else:
-            self.buffer = gtk.TextBuffer()
-            sourceview = gtk.TextView(self.buffer)
-
-        sourceview.set_editable(False)
-        sourceview.modify_font(pango.FontDescription("Monospace"))
-        scrollwin_diff = self.glade.get_widget('scrolledwindow_diff_diff')
-        scrollwin_diff.add(sourceview)
-    
-    def _init_diff(self):
-        """ Generate initial diff. """
-        self.model.clear()
-        delta = self.wt.changes_from(self.old_tree)
-
-        self.model.append(None, [ _('Complete Diff'), "" ])
-
-        if len(delta.added):
-            titer = self.model.append(None, [ _('Added'), None ])
-            for path, id, kind in delta.added:
-                self.model.append(titer, [ path, path ])
-
-        if len(delta.removed):
-            titer = self.model.append(None, [ _('Removed'), None ])
-            for path, id, kind in delta.removed:
-                self.model.append(titer, [ path, path ])
-
-        if len(delta.renamed):
-            titer = self.model.append(None, [ _('Renamed'), None ])
-            for oldpath, newpath, id, kind, text_modified, meta_modified \
-                    in delta.renamed:
-                self.model.append(titer, [ oldpath, newpath ])
-
-        if len(delta.modified):
-            titer = self.model.append(None, [ _('Modified'), None ])
-            for path, id, kind, text_modified, meta_modified in delta.modified:
-                self.model.append(titer, [ path, path ])
-
-        self.treeview.expand_all()
-    
-    def cursor_changed(self, *args):
-        """ Callback when the TreeView cursor changes. """
-        (path, col) = self.treeview.get_cursor()
-        specific_files = [ self.model[path][1] ]
-        if specific_files == [ None ]:
-            return
-        elif specific_files == [ "" ]:
-            specific_files = []
-
-        s = StringIO()
-        show_diff_trees(self.old_tree, self.wt, s, specific_files)
-        self.buffer.set_text(s.getvalue())
-    
-    def close(self, widget=None):
-        self.window.destroy()

=== modified file 'olive/handler.py'
--- olive/handler.py	2006-09-27 18:08:35 +0000
+++ olive/handler.py	2006-09-27 19:52:46 +0000
@@ -22,11 +22,9 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+
+import gtk
+import gtk.glade
 
 import bzrlib.errors as errors
 from bzrlib.branch import Branch
@@ -38,11 +36,10 @@
 
 class OliveHandler:
     """ Signal handler class for Olive. """
-    def __init__(self, gladefile, comm):
-        self.gladefile = gladefile
+    def __init__(self,  comm):
         self.comm = comm
         
-        self.menu = OliveMenu(self.gladefile, self.comm)
+        self.menu = OliveMenu(self.comm)
     
     def on_about_activate(self, widget):
         about()
@@ -51,27 +48,27 @@
         """ Add file(s)... menu handler. """
         from add import OliveAdd
         wt, path = WorkingTree.open_containing(self.comm.get_path())
-        add = OliveAdd(self.gladefile, wt, path, 
+        add = OliveAdd(wt, path, 
                 self.comm.get_selected_right())
         add.display()
     
     def on_menuitem_branch_get_activate(self, widget):
         """ Branch/Get... menu handler. """
         from branch import OliveBranch
-        branch = OliveBranch(self.gladefile, self.comm)
+        branch = OliveBranch(self.comm)
         branch.display()
     
     def on_menuitem_branch_checkout_activate(self, widget):
         """ Branch/Checkout... menu handler. """
         from checkout import OliveCheckout
-        checkout = OliveCheckout(self.gladefile, self.comm)
+        checkout = OliveCheckout(self.comm)
         checkout.display()
     
     def on_menuitem_branch_commit_activate(self, widget):
         """ Branch/Commit... menu handler. """
         from commit import OliveCommit
         wt, path = WorkingTree.open_containing(self.comm.get_path())
-        commit = OliveCommit(self.gladefile, wt, path)
+        commit = OliveCommit(wt, path)
         commit.display()
     
     def on_menuitem_branch_missing_revisions_activate(self, widget):
@@ -158,14 +155,14 @@
     def on_menuitem_branch_push_activate(self, widget):
         """ Branch/Push... menu handler. """
         from push import OlivePush
-        push = OlivePush(self.gladefile, self.comm)
+        push = OlivePush(self.comm)
         push.display()
     
     def on_menuitem_branch_status_activate(self, widget):
         """ Branch/Status... menu handler. """
         from status import OliveStatus
         wt, wtpath = WorkingTree.open_containing(self.comm.get_path())
-        status = OliveStatus(self.gladefile, wt, wtpath)
+        status = OliveStatus(wt, wtpath)
         status.display()
     
     def on_menuitem_branch_initialize_activate(self, widget):
@@ -206,25 +203,25 @@
     def on_menuitem_file_make_directory_activate(self, widget):
         """ File/Make directory... menu handler. """
         from mkdir import OliveMkdir
-        mkdir = OliveMkdir(self.gladefile, self.comm)
+        mkdir = OliveMkdir(self.comm)
         mkdir.display()
     
     def on_menuitem_file_move_activate(self, widget):
         """ File/Move... menu handler. """
         from move import OliveMove
-        move = OliveMove(self.gladefile, self.comm)
+        move = OliveMove(self.comm)
         move.display()
     
     def on_menuitem_file_rename_activate(self, widget):
         """ File/Rename... menu handler. """
         from rename import OliveRename
-        rename = OliveRename(self.gladefile, self.comm)
+        rename = OliveRename(self.comm)
         rename.display()
 
     def on_menuitem_remove_file_activate(self, widget):
         """ Remove (unversion) selected file. """
         from remove import OliveRemove
-        remove = OliveRemove(self.gladefile, self.comm)
+        remove = OliveRemove(self.comm)
         remove.display()
     
     def on_menuitem_stats_diff_activate(self, widget):
@@ -239,13 +236,13 @@
     def on_menuitem_stats_infos_activate(self, widget):
         """ Statistics/Informations... menu handler. """
         from info import OliveInfo
-        info = OliveInfo(self.gladefile, self.comm)
+        info = OliveInfo(self.comm)
         info.display()
     
     def on_menuitem_stats_log_activate(self, widget):
         """ Statistics/Log... menu handler. """
         from log import OliveLog
-        log = OliveLog(self.gladefile, self.comm)
+        log = OliveLog(self.comm)
         log.display()
     
     def on_menuitem_view_refresh_activate(self, widget):

=== modified file 'olive/info.py'
--- olive/info.py	2006-09-27 17:49:18 +0000
+++ olive/info.py	2006-09-27 19:52:46 +0000
@@ -21,16 +21,16 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-    import gobject
-    import pango
-except:
-    sys.exit(1)
+
+import gtk
+import gtk.glade
+import gobject
+import pango
 
 import bzrlib.errors as errors
 
+from olive import gladefile
+
 def info(location):
     """ Get info about branch, working tree, and repository
     
@@ -144,10 +144,9 @@
 
 class OliveInfo:
     """ Display Informations window and perform the needed actions. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Informations window. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_info', 'olive-gtk')
+        self.glade = gtk.glade.XML(gladefile, 'window_info', 'olive-gtk')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/log.py'
--- olive/log.py	2006-09-27 17:43:04 +0000
+++ olive/log.py	2006-09-27 19:52:46 +0000
@@ -36,11 +36,12 @@
 
 from dialog import error_dialog
 
+from olive import gladefile
+
 class OliveLog:
     """ Display Log (bzrk) window and perform the needed actions. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Log (bzrk) window. """
-        self.gladefile = gladefile
 
         # Communication object
         self.comm = comm

=== modified file 'olive/menu.py'
--- olive/menu.py	2006-09-27 17:38:39 +0000
+++ olive/menu.py	2006-09-27 19:52:46 +0000
@@ -22,11 +22,8 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+
+import gtk
 
 import bzrlib.errors as errors
 from dialog import error_dialog
@@ -35,7 +32,7 @@
 
 class OliveMenu:
     """ This class is responsible for building the context menus. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         # Load the UI file
         if sys.platform == 'win32':
             self.uifile = os.path.dirname(sys.executable) + "/share/olive/cmenu.ui"
@@ -51,7 +48,6 @@
                 print _('UI description file cannot be found.')
                 sys.exit(1)
         
-        self.gladefile = gladefile
         self.comm = comm
         
         # Create the file list context menu
@@ -205,13 +201,13 @@
         """ Right context menu -> Commit """
         from commit import OliveCommit
         wt, path = WorkingTree.open_containing(self.comm.get_path())
-        commit = OliveCommit(self.gladefile, wt, path)
+        commit = OliveCommit(wt, path)
         commit.display()
     
     def diff(self, action):
         """ Right context menu -> Diff """
         from diff import OliveDiff
-        diff = OliveDiff(self.gladefile, self.comm)
+        diff = OliveDiff(self.comm)
         diff.display()
     
     def bookmark(self, action):
@@ -230,7 +226,7 @@
         from bookmark import OliveBookmark
 
         if self.comm.get_selected_left() != None:
-            bookmark = OliveBookmark(self.gladefile, self.comm)
+            bookmark = OliveBookmark(self.comm)
             bookmark.display()
 
     def remove_bookmark(self, action):
@@ -254,5 +250,5 @@
     def diff_all(self, action):
         """ Diff toolbutton -> All... """
         from diff import OliveDiff
-        diff = OliveDiff(self.gladefile, self.comm)
+        diff = OliveDiff(self.comm)
         diff.display()

=== modified file 'olive/mkdir.py'
--- olive/mkdir.py	2006-09-27 17:49:18 +0000
+++ olive/mkdir.py	2006-09-27 19:52:46 +0000
@@ -22,23 +22,19 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+
+import gtk
+import gtk.glade
 
 import bzrlib.errors as errors
 
+from olive import gladefile
+
 class OliveMkdir:
     """ Display the Make directory dialog and perform the needed actions. """
-    def __init__(self, gladefile, wt, wtpath, dialog):
+    def __init__(self, wt, wtpath):
         """ Initialize the Make directory dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_mkdir', 'olive-gtk')
-        
-        # Dialog object
-        = dialog
+        self.glade = gtk.glade.XML(gladefile, 'window_mkdir', 'olive-gtk')
         
         self.window = self.glade.get_widget('window_mkdir')
         

=== modified file 'olive/move.py'
--- olive/move.py	2006-09-27 17:49:18 +0000
+++ olive/move.py	2006-09-27 19:52:46 +0000
@@ -22,20 +22,18 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+import gtk
+import gtk.glade
 
 import bzrlib.errors as errors
 
+from olive import gladefile
+
 class OliveMove:
     """ Display the Move dialog and perform the needed actions. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Move dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_move', 'olive-gtk')
+        self.glade = gtk.glade.XML(gladefile, 'window_move', 'olive-gtk')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/push.py'
--- olive/push.py	2006-09-27 17:49:18 +0000
+++ olive/push.py	2006-09-27 19:52:46 +0000
@@ -21,21 +21,20 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.gdk
-    import gtk.glade
-except:
-    sys.exit(1)
+	
+import gtk
+import gtk.gdk
+import gtk.glade
 
 import bzrlib.errors as errors
 
+from olive import gladefile
+
 class OlivePush:
     """ Display Push dialog and perform the needed actions. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Push dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_push')
+        self.glade = gtk.glade.XML(gladefile, 'window_push')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/remove.py'
--- olive/remove.py	2006-09-27 17:49:18 +0000
+++ olive/remove.py	2006-09-27 19:52:46 +0000
@@ -21,21 +21,19 @@
     pygtk.require("2.0")
 except:
     pass
-try:
-    import gtk
-    import gtk.glade
-except:
-    sys.exit(1)
+import gtk
+import gtk.glade
 
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
+from olive import gladefile
+
 class OliveRemove:
     """ Display the Remove file(s) dialog and perform the needed actions. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Remove file(s) dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_remove')
+        self.glade = gtk.glade.XML(gladefile, 'window_remove')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/rename.py'
--- olive/rename.py	2006-09-27 17:49:18 +0000
+++ olive/rename.py	2006-09-27 19:52:46 +0000
@@ -32,10 +32,9 @@
 
 class OliveRename:
     """ Display the Rename dialog and perform the needed actions. """
-    def __init__(self, gladefile, comm):
+    def __init__(self, comm):
         """ Initialize the Rename dialog. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_rename')
+        self.glade = gtk.glade.XML(gladefile, 'window_rename')
         
         # Communication object
         self.comm = comm

=== modified file 'olive/status.py'
--- olive/status.py	2006-09-27 17:49:18 +0000
+++ olive/status.py	2006-09-27 19:52:46 +0000
@@ -37,12 +37,13 @@
 
 from dialog import OliveDialog
 
+from olive import gladefile
+
 class OliveStatus:
     """ Display Status window and perform the needed actions. """
     def __init__(self, gladefile, wt, wtpath):
         """ Initialize the Status window. """
-        self.gladefile = gladefile
-        self.glade = gtk.glade.XML(self.gladefile, 'window_status')
+        self.glade = gtk.glade.XML(gladefile, 'window_status')
         
         # Get the Status window widget
         self.window = self.glade.get_widget('window_status')

